@@ -35,3 +35,15 @@ class Location:
         """
         yield self._x;
         yield self._y;
+
+    def __getitem__(self, item):
+        """
+        Allows the location to be accessed as a tuple
+        """
+
+        if item == 0:
+            return self._x;
+        elif item == 1:
+            return self._y;
+        else:
+            raise IndexError(f'Accessed index beyond x and y, index: {item}.');
